@@ -15,6 +15,7 @@
 
 #include <KAboutData>
 #include <KConfig>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -27,6 +28,7 @@
 #include "booklistmodel.h"
 #include "bookserver.h"
 #include "clipboard.h"
+#include "colorschemer.h"
 #include "config.h"
 #include "contentlist/contentlist.h"
 #include "contentlist/contentquery.h"
@@ -72,22 +74,24 @@ int main(int argc, char *argv[])
     about.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=arianna");
 
     KAboutData::setApplicationData(about);
+    KCrash::initialize();
+
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.arianna")));
 
     KDBusService service(KDBusService::Unique);
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Epub reader"));
-    parser.addPositionalArgument(QLatin1String("file"), i18n("Epub file to open"));
+    parser.addPositionalArgument(QStringLiteral("file"), i18n("Epub file to open"));
 
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
 
     Clipboard clipboard;
+    ColorSchemer colorScheme;
     Format format;
     Navigation navigation;
     qmlRegisterSingletonInstance("org.kde.arianna", 1, 0, "Config", Config::self());
@@ -124,35 +128,24 @@ int main(int argc, char *argv[])
 
                                  if (arguments.count() > 1) {
                                      const auto entry = BookDatabase::self().loadEntry(arguments[1]);
-                                     if (auto book = entry) {
-                                         Q_EMIT navigation.openBook(arguments[1], book->locations, book->currentLocation);
+                                     if (entry) {
+                                         Q_EMIT navigation.openBook(arguments[1], entry->locations, entry->currentLocation, *entry);
                                      } else {
-                                         Q_EMIT navigation.openBook(arguments[1], {}, {});
+                                         Q_EMIT navigation.openBook(arguments[1], {}, {}, BookEntry{});
                                      }
                                  }
                                  return;
                              }
                          }
                      });
-    const auto rootObjects = engine.rootObjects();
-    for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow *>(obj);
-        if (view) {
-            KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-            KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
-            KWindowConfig::restoreWindowSize(view, windowGroup);
-            KWindowConfig::restoreWindowPosition(view, windowGroup);
-            break;
-        }
-    }
 
     const QStringList args = parser.positionalArguments();
     if (!args.isEmpty()) {
         const auto entry = BookDatabase::self().loadEntry(args[0]);
-        if (const auto book = entry) {
-            Q_EMIT navigation.openBook(args[0], book->locations, book->currentLocation);
+        if (entry) {
+            Q_EMIT navigation.openBook(args[0], entry->locations, entry->currentLocation, *entry);
         } else {
-            Q_EMIT navigation.openBook(args[0], {}, {});
+            Q_EMIT navigation.openBook(args[0], {}, {}, BookEntry{});
         }
     }
 
